@@ -287,9 +287,12 @@ def cython_exts(build_deps=None, build_exts=None, build_opts=None, path=MODULEDI
         build_deps.append('cython')
         exts.extend(cython_exts)
 
-    build_exts.extend(
-        Extension(os.path.splitext(ext)[0].replace(os.path.sep, '.'), [ext], **build_opts)
-        for ext in exts)
+    for ext in exts:
+        # strip package dir
+        module = ext.rpartition(PACKAGEDIR)[-1].lstrip(os.path.sep)
+        # strip file extension and translate to module namespace
+        module = os.path.splitext(module)[0].replace(os.path.sep, '.')
+        build_exts.append(Extension(module, [ext], **build_opts))
 
     return build_deps, build_exts
 
@@ -319,11 +322,11 @@ class sdist(dst_sdist.sdist):
         """
         with syspath(PACKAGEDIR, MODULE == 'snakeoil'):
             from snakeoil.version import get_git_version
-        log.info('generating _verinfo')
         data = get_git_version(base_dir)
         if not data:
             return
         path = os.path.join(base_dir, '_verinfo.py')
+        log.info('generating version info: %s' % path)
         with open(path, 'w') as f:
             f.write('version_info=%r' % (data,))
 
@@ -388,7 +391,7 @@ class build_py(dst_build_py.build_py):
         if not os.path.exists(ver_path):
             with syspath(PACKAGEDIR, MODULE == 'snakeoil'):
                 from snakeoil.version import get_git_version
-            log.info('generating _verinfo')
+            log.info('generating version info: %s' % ver_path)
             with open(ver_path, 'w') as f:
                 f.write("version_info=%r" % (get_git_version('.'),))
             self.byte_compile([ver_path])
